@@ -1,6 +1,7 @@
 import os
 import yaml
-from Constants import ENV_CONFIG_FOLDER, ENV_CONFIG_PROJECT_NAME, ENV_CONFIG_FILE_EXTENSION, ENV_CONFIG_ENVIRONMENT, \
+from adaendra_python_config_loader.Constants import ENV_CONFIG_FOLDER, ENV_CONFIG_PROJECT_NAME, \
+    ENV_CONFIG_FILE_EXTENSION, ENV_CONFIG_ENVIRONMENT, \
     DEFAULT_CONFIG_FOLDER, DEFAULT_CONFIG_PROJECT_NAME, DEFAULT_CONFIG_FILE_EXTENSION, \
     FILE_EXT_YAML, FILE_EXT_YML, FILE_EXT_JSON
 
